#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

set -e

#GLOBALS
SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi
BASE_NAME=$(basename "$0")
COMMAND_NAME="${COMMAND_NAME:-$BASE_NAME}"

readonly SCRIPT_DIR
readonly MODULES_DIR

export KUBECONFIG=${KUBECONFIG:-/etc/rancher/rke2/rke2.yaml}
export PATH=$PATH:/var/lib/rancher/rke2/bin:${SCRIPT_DIR}/Fabric_Installer/bin:/usr/local/bin

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/certificate_utils.sh

function display_usage() {
  echo
  echo "***************************************************************************************"
  echo
  echo "Manage additional CA certificates, this can be used to add sql server CA"
  echo 
  echo "Usage:"
  echo "  $COMMAND_NAME [command]"
  echo "  $COMMAND_NAME [flags]"
  echo 
  echo "Available Commands:"
  echo "  update                              Update the additional trusted CA certificates."
  echo 
  echo "  get                                 Get the additional trusted CA certificates"
  echo
  echo "Flags:"
  echo "  -h|--help                           Display help"
  echo
  echo "***************************************************************************************"
  echo
}

function parse_long_args() {
  while (("$#")); do
    case "$1" in
    -d | --debug)
      info "Running in debug"
      shift
      set -x
      ;;

    -h | --help)
      display_usage
      shift
      exit 0
      ;;

    get)
      shift
      export COMMAND_NAME="${COMMAND_NAME} get" 
      get_additional_ca_certs "$@";
    ;;

    update)
      shift
      export COMMAND_NAME="${COMMAND_NAME} update" 
      update_additional_ca_certs "$@";
    ;;

    add)
      shift
      export COMMAND_NAME="${COMMAND_NAME} update" 
      add_additional_ca_certs "$@";
    ;;

    -*|*) # unsupported flags
      display_usage
      error "Error: Unsupported flag $1"
      exit 1
      ;;
    esac
  done

  display_usage
}

function update_additional_ca_certs() {
  if "${SCRIPT_DIR}"/update.sh "$@"; then
    exit 0
  fi
  exit 1
}

function get_additional_ca_certs() {
  if "${SCRIPT_DIR}"/get.sh "$@"; then
    exit 0
  fi
  exit 1
}

function main() {
  parse_long_args "$@"
  exit 0
}

main "$@"

