#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

set -e

#GLOBALS
SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
BASE_NAME=$(basename "$0")
COMMAND_NAME="${COMMAND_NAME:-$BASE_NAME}"

readonly SCRIPT_DIR

export KUBECONFIG=${KUBECONFIG:-/etc/rancher/rke2/rke2.yaml}
export PATH=$PATH:${SCRIPT_DIR}/../../../bin

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh

function display_usage() {
  echo
  echo "***************************************************************************************"
  echo
  echo "Manage Windows Authentication Setting"
  echo 
  echo "Usage:"
  echo "  $COMMAND_NAME [command]"
  echo 
  echo "Available Commands:"
  echo "  update                        Update the Windows authentication settings"
  echo
  echo "Flags:"
  echo "  -h|--help                     Display help"
  echo "  -d|--debug                    Running in debug mode"
  echo
  echo "***************************************************************************************"
  echo
}

function parse_long_args() {
  while (("$#")); do
    case "$1" in
    -d | --debug)
      info "Running in debug"
      shift
      set -x
      ;;

    -h | --help)
      display_usage
      shift
      exit 0
      ;;

    update)
      shift
      export COMMAND_NAME="${COMMAND_NAME} update" 
      update_win_auth "$@"
    ;;

    -*|*) # unsupported flags
      display_usage
      exit 1
      ;;
    esac
  done
}

function update_win_auth() {
  if "${SCRIPT_DIR}"/update.sh "$@"; then
    exit 0
  fi
  exit 1
}

function main() {
  if [ $# -eq 0 ]; then
    display_usage
    exit
  fi

  parse_long_args "$@"
    
  exit 0
}

main "$@"