#! /bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

set -e

#GLOBALS
BASE_NAME=$(basename "$0")
COMMAND_NAME="${COMMAND_NAME:-$BASE_NAME}"

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/argocd_utils.sh

function enable_win_auth() {
    argocd app set uipath -p "global.userInputs.identity.krb5KeytabSecret=${KEYTAB}"

    argocd app sync uipath
}

function display_usage() {
  echo
  echo "***************************************************************************************"
  echo
  echo "Update Windows Authentication setting"
  echo 
  echo "Usage:"
  echo "  $COMMAND_NAME [flags]"
  echo 
  echo "Flags:"
  echo "  -d|--debug            Run this script in debug mode"
  echo "  -h|--help             Display help"
  echo "  --keytab              (Required) Keytab file in base64 string format"
  echo
  echo "***************************************************************************************"
  echo
}

function parse_long_args() {
  while (("$#")); do
    case "$1" in
    -d | --debug)
      info "Running in debug"
      shift
      set -x
      ;;

    -h | --help)
      display_usage
      shift
      exit 0
      ;;

    --keytab)
      KEYTAB=$2
      shift 2
      ;;

    -*|*) # unsupported flags
      display_usage
      exit 1
      ;;
    esac
  done

  display_usage
}

KEYTAB="PLACEHOLDER"

function main() {
    if [ $# -lt 2 ] 
    then
      display_usage
      exit 1
    fi

    parse_long_args "$@"

    echo "Updating Windows Auth....."
    if enable_win_auth; then
        echo "Success!"
        echo "Learn how to enable Windows Auth <link> "
        exit 0
    else 
        echo "Failed!"
        echo "For more info on Windows Auth, <link>"
        exit 1
    fi
}


main "$@"
exit 0