#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

NODE_ROLE=NODE_ROLE_PLACEHOLDER
BACKUP_DIR=BACKUP_MOUNT_PLACEHOLDER/NODE_PLACEHOLDER

if [[ "${NODE_ROLE}" != "agent" ]]; then
  # copy tls to backup
  mkdir -p ${BACKUP_DIR}/tls
  cp -r /var/lib/rancher/rke2/server/tls/* ${BACKUP_DIR}/tls/.

  # copy encryption
  mkdir -p ${BACKUP_DIR}/cred
  cp -r /var/lib/rancher/rke2/server/cred/* ${BACKUP_DIR}/cred/.

  # copy latest 2 snapshots to backup
  mkdir -p ${BACKUP_DIR}/snapshots
  # shellcheck disable=SC2012
  ls -trl /var/lib/rancher/rke2/server/db/snapshots --ignore='*part' | tail -n -2| awk '{print $9}'| xargs -I {} cp -r /var/lib/rancher/rke2/server/db/snapshots/{} "${BACKUP_DIR}/snapshots/{}"

  # remove old snapshots
  # shellcheck disable=SC2012
  ls -tl ${BACKUP_DIR}/snapshots/| tail -n +4| awk '{print $9}'| xargs -I {} rm -rf "${BACKUP_DIR}/snapshots/{}"
fi

# copy node password
mkdir -p ${BACKUP_DIR}/node
cp -r /etc/rancher/node/* ${BACKUP_DIR}/node/.

# copy longhorn disk config
longhorn_disk_paths=$(find / -maxdepth 2 -name longhorn-disk.cfg | grep longhorn-disk.cfg) || true
for longhorn_disk_path in ${longhorn_disk_paths}; do
  longhorn_disk_dir="$(dirname "${longhorn_disk_path}")"
  mkdir -p "${BACKUP_DIR}/longhorn_disk_metadata/${longhorn_disk_dir}"
  cp -r "${longhorn_disk_path}" ${BACKUP_DIR}/longhorn_disk_metadata/"${longhorn_disk_dir}"
done

# copy rook-ceph keyrings
mkdir -p ${BACKUP_DIR}/rook-ceph
file_names=$(find /var/lib/rook/rook-ceph/ -name "keyring")
for file_name in ${file_names}; do
  updated_file_name=$(echo "${file_name}"| sed -e "s|/var/lib/rook/rook-ceph/||g"|sed -e "s|/|_|g")
  cp "${file_name}" "${BACKUP_DIR}/rook-ceph/${updated_file_name}"
done
