#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

set -e

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi

readonly SCRIPT_DIR
readonly MODULES_DIR

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh

function main() {
    echo "Patching istio gateway service"
    ##nodeIps=$(kubectl get nodes -o jsonpath='{ $.items[*].status.addresses[?(@.type=="InternalIP")].address }')
    ##nodeIpArray=$(jq -r -n -c --arg nodeIps "$nodeIps" '$nodeIps | split(" ")')
    nodeIpArray=$(kubectl get nodes -o json | jq -c -r  '[.items[].status.addresses[] | select(.type == "InternalIP").address]')
    fqdnIps=$(getent ahosts  "${FQDN}" | awk '{print $1}' | sort | uniq)
    istioExternalIps=$(jq -n --argjson nodeIpArray "${nodeIpArray}" --arg fqdnIps "${fqdnIps}" --arg additionalExternalIps "${ISTIO_ADDITIONAL_EXTERNAL_IPS}" '[($nodeIpArray +  ($fqdnIps | split("\n")) + ($additionalExternalIps | split(" ")) ) | sort | unique | .[] | select(. != "") | gsub("^\\s+|\\s+$";"")]')
    kubectl -n istio-system patch svc istio-ingressgateway  -p "{\"spec\":{\"externalIPs\":${istioExternalIps}}}" \
        || error "istio-ingressgateway patch failed"

    if kubectl -n longhorn-system get networkpolicy longhorn-networkpolicy;
    then
      echo "Patching longhorn network policy"
      flannelDIpsArray=$(kubectl get nodes -o json | jq -c -r  '.items[].spec.podCIDR | split("/") | .[0] + "/32"')
      nodeIpsArray=$(kubectl get nodes -o json | jq -c -r  '.items[].status.addresses[] | select(.type == "InternalIP").address | . + "/32"')
      currentAddresses=$(kubectl -n longhorn-system get networkpolicy longhorn-networkpolicy -o json | jq '.spec.ingress[0].from' | jq -c -r '[.[].ipBlock.cidr]')
      fromObject=$(kubectl -n longhorn-system get networkpolicy longhorn-networkpolicy -o json | jq '.spec.ingress[0].from')
      
      for ip in ${flannelDIpsArray}; do
        if [[ ! "${currentAddresses[*]}" =~ ${ip} ]]; 
        then
          fromObject=$(echo "${fromObject}" | jq --arg ip "${ip}" '. += [{ "ipBlock" : { "cidr": $ip } }]')
        fi
      done

      for nodeIp in ${nodeIpsArray}
      do
        if [[ ! "${currentAddresses[*]}" =~ ${nodeIp} ]];
        then
          fromObject=$(echo "${fromObject}" | jq --arg ip "${nodeIp}" '. += [{ "ipBlock" : { "cidr": $ip } }]')
        fi
      done
      kubectl -n longhorn-system patch networkpolicy longhorn-networkpolicy -p  "{ \"spec\" : {\"ingress\" : [ { \"from\": ${fromObject} } ] } }" --type=merge
      echo "Patched longhorn network policy with nodeIP"
    fi
}

main "$@"