local string_helper = {}

-- Parse query paramter value
local function decode_url(s)
    s = s:gsub('+', ' ')
        :gsub('%%(%x%x)', function(h)
                              return string.char(tonumber(h, 16))
                        end)
    return s
end

-- Extract query parameters from url to a map
function string_helper.parse_url(s)
    local ans = {}
    for k,v in s:gmatch('([^&=?]-)=([^&=?]+)' ) do
        ans[ k ] = decode_url(v)
    end
    return ans
end

-- Get value from a key:value pair string that separated by space, given its key
function string_helper.get_value(str, key)
    for element in str:gmatch("%S+") do
        local index = string.find(string.lower(element), string.lower(key))
        if index ~= nil then
            index = string.find(element, ":")
            local val = string.sub(element, index+1)
            return val
        end
    end
end

-- Skip filters when encounter reserved words
function string_helper.skip_reserved_words(request_handle, reserved_list, param)
    for i, v in ipairs(reserved_list) do
        local pos = string.find(string.lower(param), v)
        local is_reserved = pos ~= nill and (pos - 1 + string.len(v)) == string.len(param)
        if is_reserved then
            request_handle:logInfo(v.." is found at "..pos..", skip request filter...")
            return true
        end
    end
    return false
end

-- Get port from request, returns default 443 if no port specified
function string_helper.get_port(request_handle)
    local authority = request_handle:headers():get(":authority")
    local port_index = string.find(authority, ":")
    if port_index ~= nil then
        local port = tonumber(string.sub(authority, port_index+1))
        return port
    end
    return 443
end

-- Extract FQDN from FQDN:PORT
function string_helper.get_fqdn(request_handle)
    local req_authority = request_handle:headers():get(":authority")
    local port_index = string.find(req_authority, ":")
    local fqdn

    if port_index ~= nil then
        fqdn = tostring(string.sub(req_authority, 0, port_index-1))
    else
        fqdn = req_authority
    end
    return fqdn
end

return string_helper
