local luaunit = require("luaunit")

local json_parser = require("src.json_parser")

function test_parse_json()
    local id = "90da0c51-b76c-47de-a95c-76d71736c73e"
    local json = "{\"organizationId\":\""..id.."\",\"isDeleted\":false}"

    local dto = json_parser.parse_json(json)
    
    luaunit.assertEquals(dto.organizationId, id)
    luaunit.assertFalse(dto.isDeleted)
end

function test_parse_json_with_nested_data()
    local guid, service, weight = "90da0c51-b76c-47de-a95c-76d71736c73e", "orchestrator", 100
    local json = "{\"serviceMetadata\":{\"id\":\""..service.."\",\"authorization\":{\"audience\":\""..service.."\",\"clientId\":\""..guid.."\"}},\"scaleUnits\":[{\"id\":\""..guid.."\",\"uri\":\"http://orchestrator\",\"supportedRegions\":{\"Europe\":"..weight.."}}]}"
    
    local dto = json_parser.parse_json(json)
    luaunit.assertNotNil(dto)

    local serviceMetadata = dto.serviceMetadata
    luaunit.assertNotNil(serviceMetadata)
    luaunit.assertEquals(serviceMetadata.id, service)
    luaunit.assertEquals(serviceMetadata.authorization.audience, service)
    luaunit.assertEquals(serviceMetadata.authorization.clientId, guid)

    local scaleUnits = dto.scaleUnits
    luaunit.assertNotNil(scaleUnits)
    luaunit.assertEquals(#scaleUnits, 1)
    luaunit.assertEquals(scaleUnits[1].id, guid)
    luaunit.assertEquals(scaleUnits[1].supportedRegions.Europe, weight)
end

function test_parse_json_with_invalid_json_should_error()
    local json = "{\"organizationId\":}"

    luaunit.assertError(json_parser.parse_json, json)
    luaunit.assertErrorMsgContains("Invalid json syntax", json_parser.parse_json, json)
end

luaunit.LuaUnit:run()
