local luaunit = require("luaunit")

local string_helper = require("src.string_helper")
local mock_request_handle = require("mock_request_handle")

function test_parse_url()
    local query = "param"
    local param = "key1:value1 key2:value2"

    local res = string_helper.parse_url("/api/query?"..query.."="..param)

    luaunit.assertEquals(res[query], param)
end

function test_get_value()
    local key = "key"
    local value = "val"

    local res = string_helper.get_value(key..":"..value, key)

    luaunit.assertEquals(res, value)
end

function test_skip_reserved_words_should_return_true_for_reserved_word()
    local request_handle = mock_request_handle:new(nil)
    local reserved_word = "word"
    local reserved_list = { reserved_word }

    local res = string_helper.skip_reserved_words(request_handle, reserved_list, reserved_word)

    luaunit.assertEvalToTrue(res)
end

function test_skip_reserved_words_should_return_false_for_non_reserved_word()
    local request_handle = mock_request_handle:new(nil)
    local non_reserved_word = "non_reserved"
    local reserved_list = { "reserved_word" }

    local res = string_helper.skip_reserved_words(request_handle, reserved_list, non_reserved_word)

    luaunit.assertEvalToFalse(res)
end

function test_skip_get_port_return_443()
    local request_handle = mock_request_handle:new(nil)
    request_handle:headers():replace(":authority", "dns")

    local res = string_helper.get_port(request_handle)

    luaunit.assertEquals(res, 443)
end

function test_skip_get_port_return_given_port()
    local request_handle = mock_request_handle:new(nil)
    local port = 15000
    request_handle:headers():replace(":authority", "dns:"..port)

    local res = string_helper.get_port(request_handle)

    luaunit.assertEquals(res, port)
end

function test_get_fqdn_without_port()
    local request_handle = mock_request_handle:new(nil)
    local dns = "test.com"
    request_handle:headers():replace(":authority", dns)

    local fqdn = string_helper.get_fqdn(request_handle)

    luaunit.assertEquals(fqdn, dns)
end

function test_get_fqdn_with_port()
    local request_handle = mock_request_handle:new(nil)
    local dns = "test.com"
    request_handle:headers():replace(":authority", dns..":15000")

    local fqdn = string_helper.get_fqdn(request_handle)

    luaunit.assertEquals(fqdn, dns)
end

luaunit.LuaUnit:run()
