#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

MODULES_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi

readonly MODULES_DIR
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh

function parse_arguments() {
  local machine_installation_type="single_node"
  local product_installation_type="core_platform"
  local is_multi_node_installation
  is_multi_node_installation="$(get_optional_json_value ".multinode")"

  if [[ "${is_multi_node_installation}" == "true" ]]; then
      machine_installation_type="multi_node"
  fi

  if [[ "$(is_full_installation)" == "true" ]]; then
    product_installation_type="full_automation_suite"
  fi

  MINIMUM_CLUSTER_CPU=$(get_mandatory_json_value ".infra.hardware_requirements.${machine_installation_type}.${product_installation_type}.cluster_cpu")
  MINIMUM_CLUSTER_MEMORY=$(get_mandatory_json_value ".infra.hardware_requirements.${machine_installation_type}.${product_installation_type}.cluster_memory")

  MINIMUM_CLUSTER_MEMORY_EXCLUDING_RESERVED=$(((MINIMUM_CLUSTER_MEMORY*9)/10))
}

function is_service_installation_allowed() {
  total_cpu=0
  total_memory_in_kb=0
  local is_cluster_requirement_satisfied="true"
  nodes=$(kubectl get node --no-headers -o custom-columns=NAME:.metadata.name)
  local warnings=()

  for node in $nodes; do
    cpu=$(kubectl get node "${node}" -o json | jq -r '.status.capacity.cpu')
    memory=$(kubectl get node "${node}" -o json | jq -r '.status.capacity.memory' | tr -d 'Ki')
    total_cpu=$((total_cpu + cpu))
    total_memory_in_kb=$((total_memory_in_kb + memory))
  done

  # Stop installation if cpu count is less than 'minimum_cores' mentioned in defaults.json
  if (( total_cpu < MINIMUM_CLUSTER_CPU )); then
    warnings+=("Minimum CPU core requirement for cluster is ${MINIMUM_CLUSTER_CPU}")
    is_cluster_requirement_satisfied="false"
  fi

  local total_memory_in_Gb=$(( "${total_memory_in_kb}"/1024/1024 ))
  if (( total_memory_in_Gb < MINIMUM_CLUSTER_MEMORY_EXCLUDING_RESERVED )); then
    warnings+=("Minimum memory requirement for cluster is ${MINIMUM_CLUSTER_MEMORY} GiB")
    is_cluster_requirement_satisfied="false"
  fi
  
  [[ ${#warnings[@]} != 0 ]] && warn_output "Cluster Validation Failed: " "${warnings[@]}"
  echo "${is_cluster_requirement_satisfied}"
}

function main() {
  parse_arguments
  if [[ -z "${NODE_ROLE}" || "${NODE_ROLE}" == "none" || "${NODE_ROLE}" == "server" ]]; then
    local is_installation_allowed
    is_installation_allowed="$(is_service_installation_allowed)"
    
    echo "${is_installation_allowed}"
  else
    echo "true"
  fi
}

main