#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

set -e

function install_helm() {
    local MODULES_DIRECTORY
    MODULES_DIRECTORY=$1
    if ! check_package_or_command helm; then
        chmod +x "${MODULES_DIRECTORY}"/get_helm.sh
        "${MODULES_DIRECTORY}"/get_helm.sh --version v3.6.3 2>/dev/null || true
    fi
}

function install_other_packages() {
    local required_os_pkgs=(jq iscsi-initiator-utils nfs-utils rpcbind uuidgen nc util-linux openssl httpd-tools)
    for pkg in "${required_os_pkgs[@]}"; do
        if ! check_package_or_command "$pkg"; then
            pkg=${pkg//[[:blank:]]/}
            info "installing $pkg."
            yum install -y "$pkg" 2>/dev/null || true
        fi
    done
}

function enable_iscsid() {
    #To handle this scenario of iscsid service does not exists
    if [[ "$(systemctl is-enabled iscsid 2>/dev/null)" == "" ]];
    then
      error "package iscsi-initiator-utils is required but not installed."
    fi

    if ! systemctl --quiet is-active iscsid ;
    then
      echo "starting iscsid service"
      systemctl enable iscsid && systemctl start iscsid
    fi
}

function install_package_dependencies() {
    local MODULES_DIRECTORY
    MODULES_DIRECTORY=$1
    install_helm "${MODULES_DIRECTORY}"
    install_other_packages
    enable_iscsid
}