#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

set -eu

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi

readonly SCRIPT_DIR
readonly MODULES_DIR

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/upgrade_utils.sh"
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/longhornutils.sh
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/k8sutils.sh
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh

function parse_input_file() {
  INSTALL_MULTINODE="$(get_optional_json_value ".multinode")"
  export INSTALL_MULTINODE
}

function recreate_storage_class() {
    local current_replica_count
    local storage_class_name
    storage_class_name=$(kubectl get storageclass -o json | jq -r '.items[]  | select(.metadata.name =="longhorn-backup-single-replica") | .spec.volumeName')
    if [ -n "$storage_class_name" ]
    then
        current_replica_count=$(kubectl -n longhorn-system get storageclass longhorn-backup-single-replica -o json | jq -r '.parameters.numberOfReplicas')
        if [[ "$current_replica_count" == "1" || "$current_replica_count" == "" ]]
        then
            kubectl delete storageclass longhorn-backup-single-replica &>/dev/null
            rm -f "$SCRIPT_DIR"/../../Infra_Installer/longhorn/longhorn-storage-backup-one-replica-tmp.yaml &>/dev/null
            cp "$SCRIPT_DIR"/../../Infra_Installer/longhorn/longhorn-storage-backup-one-replica.yaml "$SCRIPT_DIR"/../../Infra_Installer/longhorn/longhorn-storage-backup-one-replica-tmp.yaml
            sed -i "s/REPLICA_PLACEHOLDER/2/" "$SCRIPT_DIR"/../../Infra_Installer/longhorn/longhorn-storage-backup-one-replica-tmp.yaml 
            kubectl apply -f "$SCRIPT_DIR"/../../Infra_Installer/longhorn/longhorn-storage-backup-one-replica-tmp.yaml 1>/dev/null
        fi 
    fi
}

function update_replica_count() {
    set_longhorn_url
    local volumes
    volumes=$(kubectl get pvc -A -o json | jq -r '.items[]  | select(.spec.storageClassName =="longhorn-backup-single-replica") | .spec.volumeName')
    for volume in $volumes; do
        kubectl -n longhorn-system patch volumes.longhorn.io "${volume}" --type='json' -p '[{ "op": "replace", "path": "/spec/numberOfReplicas", "value": 2 }]' 1>/dev/null
    done
}

parse_input_file
if [[ "${INSTALL_MULTINODE}" == "true" ]]; then
  recreate_storage_class && update_replica_count
fi


