#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

# Deletes the existing Redis cluster to avoid the quorum loss problem.

set -eu

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi

readonly SCRIPT_DIR
readonly MODULES_DIR

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/utils.sh


#MAIN
function main() {
  local namespace="redis-system"
  local cluster_name="redis-cluster"
  local db_name=""

  kubectl get namespace "${namespace}" &>/dev/null || {
    info "Redis namespace (${namespace}) not found. Skipping..."
    exit 0
  }

  db_name=$(kubectl -n "${namespace}" get redb \
                      -o jsonpath='{.items[0].metadata.name}' \
                      --ignore-not-found)

  [[ -n "${db_name}" ]] && {
    info "Deleting the redis database..."
    kubectl delete redb -n "${namespace}" "${db_name}" &>/dev/null &
    kubectl patch redb -n "${namespace}" "${db_name}" --type=json -p '[{"op":"remove","path":"/metadata/finalizers","value":"finalizer.redisenterprisedatabases.app.redislabs.com"}]' &>/dev/null
    }

  info "Deleting the redis cluster..."
  kubectl delete rec -n "${namespace}" "${cluster_name}" &>/dev/null &
  kubectl patch rec -n "${namespace}" "${cluster_name}" -p '{"metadata":{"finalizers":null}}' --type=merge &>/dev/null

  for job in $(kubectl get job -n "${namespace}" -l "app.kubernetes.io/name=${cluster_name}" -o jsonpath='{..metadata.name}'); do
    kubectl delete job -n "${namespace}" "${job}" &>/dev/null  || true
  done

  for pod in $(kubectl get pods -n "${namespace}" -l redis.io/role=node,redis.io/cluster="${cluster_name}" -o jsonpath='{..metadata.name}')
  do
    kubectl delete pod -n "${namespace}" --force "${pod}" &>/dev/null || true
  done

  wait && info "Existing Redis cluster and database were removed successfully"
}

export STEP=$1
# Pass additional arguments from upgrade path to main function.
main "${@:2}"
